#!/bin/bash
#
# Caddy Service

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin

config_caddy() {
  echo -ne "\n* Configuring /federated/apps/caddy container.."
  spin &
  SPINPID=$!

  if [ ! -d "/federated/apps/caddy" ]; then
    mkdir -p /federated/apps/caddy/data/data
    mkdir -p /federated/apps/caddy/data/etc/caddy
  fi

  DOMAIN_ARRAY=(${DOMAIN//./ })
  DOMAIN_FIRST=${DOMAIN_ARRAY[0]}
  DOMAIN_LAST=${DOMAIN_ARRAY[1]}

cat > /federated/apps/caddy/docker-compose.yml <<EOF
version: "3.7"

services:
  caddy:
    image: federatedcomputer/caddy:\${IMAGE_VERSION}
    container_name: www
    hostname: www.$DOMAIN
    domainname: $DOMAIN
    restart: always
    networks:
      federated:
        ipv4_address: 172.99.0.31
    extra_hosts:
      - "gitea.$DOMAIN:164.92.112.207"
    env_file:
      - ./.env
    volumes:
      - ./data/etc/caddy/Caddyfile:/etc/caddy/Caddyfile
      - ./data/data:/data

networks:
  federated:
    external: true
EOF

cat > /federated/apps/caddy/.env <<EOF
IMAGE_VERSION="latest"
VIRTUAL_PROTO=http
VIRTUAL_PORT=2019
VIRTUAL_HOST=www.$DOMAIN
EOF
chmod 600 /federated/apps/caddy/.env

cat > /federated/apps/caddy/data/etc/caddy/Caddyfile <<EOF
:2019
file_server
root * /srv/blog

route /webhook {
        webhook {
            repo https://gitea.$DOMAIN/gitea/hugowebsite
            type github
            secret $WEBHOOK_SECRET
            submodule
            token $GITEA_TOKEN_1
            path blog
            branch master
        }
    }
EOF

kill -9 $SPINPID &> /dev/null
echo -ne "done."
}
start_caddy() {
  # Start service with command to make sure it's up before proceeding
  start_service "caddy" "nc -z 172.99.0.31 2019 &> /dev/null"

  kill -9 $SPINPID &> /dev/null
  echo -ne "done."
}
