#!/bin/bash
#
# Collabora Service

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin

config_collabora() {
  echo -ne "\n* Configuring /federated/apps/collabora container.."
  spin &
  SPINPID=$!

  if [ ! -d "/federated/apps/collabora" ]; then
    mkdir -p /federated/apps/collabora/data/root/certs &> /dev/null
    cp -rf /federated/apps/dns/data/etc/letsencrypt/archive/$DOMAIN/*.pem /federated/apps/collabora/data/root/certs/
    chown 104 /federated/apps/collabora/data/root/certs/*
  fi

  DOMAIN_ARRAY=(${DOMAIN//./ })
  DOMAIN_FIRST=${DOMAIN_ARRAY[0]}
  DOMAIN_LAST=${DOMAIN_ARRAY[1]}

cat > /federated/apps/collabora/docker-compose.yml <<EOF
version: '3.7'

services:
  collabora:
    image: collabora/code:\${IMAGE_VERSION}
    container_name: collabora
    hostname: collabora.$DOMAIN
    domainname: $DOMAIN
    restart: always
    networks:
      federated:
        ipv4_address: 172.99.0.14
    extra_hosts:
      - "nextcloud.$DOMAIN:$EXTERNALIP"
    ports:
      - "9980:9980"
    volumes:
      - ./data/root:/root
      - ./data/root/certs/fullchain1.pem:/etc/coolwsd/cert.pem
      - ./data/root/certs/privkey1.pem:/etc/coolwsd/key.pem
      - ./data/root/certs/chain1.pem:/etc/coolwsd/ca-chain.cert.pem
    env_file:
      - ./.env
    cap_add:
      - MKNOD

networks:
  federated:
    external: true
EOF

cat > /federated/apps/collabora/.env <<EOF
IMAGE_VERSION="latest"
VIRTUAL_PROTO=https
VIRTUAL_PORT=9980
VIRTUAL_HOST=collabora.$DOMAIN
domain=nextcloud.$DOMAIN
server_name=collabora.$DOMAIN
EOF
chmod 600 /federated/apps/collabora/.env

kill -9 $SPINPID &> /dev/null
echo -ne "done."
}

start_collabora() {
  # Start /federated/apps/collabora with output to /dev/null
  echo -ne "\n* Starting /federated/apps/collabora service.."
  spin &
  SPINPID=$!

  if [ $DEBUG ]; then
    # Start /federated/apps/collabora with output to console for debug
    docker-compose -f /federated/apps/collabora/docker-compose.yml -p collabora up
    [ $? -eq 0 ] && echo -ne "done.\n" || fail "There was a problem starting service /federated/apps/collabora"
  else
    docker-compose -f /federated/apps/collabora/docker-compose.yml -p collabora up -d &> /dev/null

    # Keep trying collabora port 9980 to make sure it's up
    # before we proceed
    RETRY="30"
    while [ $RETRY -gt 0 ]; do
      nc -z 172.99.0.14 9980 &> /dev/null
      if [ $? -eq 0 ]; then
        break
      else
        if [ "$RETRY" == 1 ]; then
          docker-compose -f /federated/apps/collabora/docker-compose.yml -p collabora down &> /dev/null
          kill -9 $SPINPID &> /dev/null
          fail "There was a problem starting service /federated/apps/collabora\nCheck the output of 'docker logs collabora' or turn on\ndebug with -d"
        fi
        ((RETRY--))
        sleep 7
      fi
    done
  fi
  
  kill -9 $SPINPID &> /dev/null
  echo -ne "done."
}
