#!/bin/bash
#
# Proxy Service

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin

config_proxy() {
  echo -ne "\n* Configuring /federated/apps/proxy container.."
  spin &
  SPINPID=$!

  if [ ! -d "/federated/apps/proxy" ]; then
    mkdir -p /federated/apps/proxy/data/root/certs &> /dev/null
    cp /federated/apps/dns/data/etc/letsencrypt/archive/$DOMAIN/fullchain1.pem /federated/apps/proxy/data/root/certs/$DOMAIN.crt
    cp /federated/apps/dns/data/etc/letsencrypt/archive/$DOMAIN/privkey1.pem /federated/apps/proxy/data/root/certs/$DOMAIN.key
  fi

  DOMAIN_ARRAY=(${DOMAIN//./ })
  DOMAIN_FIRST=${DOMAIN_ARRAY[0]}
  DOMAIN_LAST=${DOMAIN_ARRAY[1]}

cat > /federated/apps/proxy/docker-compose.yml <<EOF
version: '3.7'

services:
  proxy:
    image: jwilder/nginx-proxy:\${IMAGE_VERSION}
    container_name: proxy
    hostname: proxy.$DOMAIN
    domainname: $DOMAIN
    restart: always
    networks:
      federated:
        ipv4_address: 172.99.0.15
    ports:
      - 80:80
      - 443:443
    volumes:
      - /var/run/docker.sock:/tmp/docker.sock:ro
      - ./data/root/certs:/etc/nginx/certs

networks:
  federated:
    external: true
EOF

cat > /federated/apps/proxy/.env <<EOF
IMAGE_VERSION="1.1"
EOF
chmod 600 /federated/apps/proxy/.env
 
kill -9 $SPINPID &> /dev/null
echo -ne "done."
}

start_proxy() {
  # Start /federated/apps/proxy with output to /dev/null
  echo -ne "\n* Starting /federated/apps/proxy service.."
  spin &
  SPINPID=$!

  if [ $DEBUG ]; then
    # Start /federated/apps/proxy with output to console for debug
    docker-compose -f /federated/apps/proxy/docker-compose.yml -p proxy up
    [ $? -eq 0 ] && echo -ne "done.\n" || fail "There was a problem starting service /federated/apps/proxy"
  else
    docker-compose -f /federated/apps/proxy/docker-compose.yml -p proxy up -d &> /dev/null

    # Keep trying proxy port 443 to make sure it's up
    # before we proceed
    RETRY="23"
    while [ $RETRY -gt 0 ]; do
      nc -z 172.99.0.15 443 &> /dev/null
      if [ $? -eq 0 ]; then
        break
      else
        if [ "$RETRY" == 1 ]; then
          docker-compose -f /federated/apps/proxy/docker-compose.yml -p proxy down &> /dev/null
          kill -9 $SPINPID &> /dev/null
          fail "There was a problem starting service /federated/apps/proxy\nCheck the output of 'docker logs proxy' or turn on\ndebug with -d"
        fi
        ((RETRY--))
        sleep 7
      fi
    done
  fi

  kill -9 $SPINPID &> /dev/null
  echo -ne "done."
}
